@@ -1212,10 +1212,17 @@ class DataSet(object):
 
     # import the methods
 
+    from nctoolkit.add_etc import abs
     from nctoolkit.add_etc import add
+    from nctoolkit.add_etc import exp
+    from nctoolkit.add_etc import log
+    from nctoolkit.add_etc import log10
     from nctoolkit.add_etc import subtract
     from nctoolkit.add_etc import multiply
     from nctoolkit.add_etc import divide
+    from nctoolkit.add_etc import power
+    from nctoolkit.add_etc import square
+    from nctoolkit.add_etc import sqrt
 
     from nctoolkit.anomaly import annual_anomaly
     from nctoolkit.anomaly import monthly_anomaly
