@@ -95,12 +95,13 @@ funs = [
     "ceil",
     "sqrt",
     "exp",
-    "log10",
+    "ln",
     "sin",
     "cos",
     "tan",
     "int",
-    "float"
+    "float",
+    "log10"
 ]
 
 translation = dict()
