@@ -38,6 +38,9 @@ def to_nc(self, out, zip=True, overwrite=False):
 
     """
 
+    if len(self) == 0:
+        raise ValueError("Failure due to empty dataset!")
+
     if os.path.basename(out) != out:
         out_dir = os.path.dirname(out)
         if os.path.exists(out_dir) == False:
